import React, { useState } from "react"
import FileBrowser from "./components/FileBrowser"
import { BrowserRouter as Router, Switch, Route, Redirect } from "react-router-dom"
import NotFound from "./components/NotFound"
import Login from "./components/Login"
import { useIsAuthQuery } from "./generated/graphql"
import { useEffect } from "react"

const App: React.FC = () => {
	const { data } = useIsAuthQuery()
	const [isAuth,setIsAuth] = useState(false)
	const [ready,setReady] = useState(false)

	useEffect(()=>{
		if (data){
			setIsAuth(data.authorized)
			setReady(true)
		}
	},[data])

	return (
		<div className="dark:text-gray-300">
			{
				ready&& 
				<Router>
					<Switch>
						{/* Private only routes */}
						{
							isAuth && [
								<Route path="/f/" component={FileBrowser} key={null} />,
								<Redirect from="/" exact to="/f/" key={null} />,
								<Redirect from="/login" exact to="/f/" key={null} />,
							]
						}

						{/* Public only routes */}
						{
							!isAuth && [
								<Route path="/login" exact key={null} >
									<Login onLogin={()=>{
										setIsAuth(true)
									}} />
								</Route>,
								<Redirect from="*" to="/login" key={null} />
							]
						}

						{/* Public & private routes */}
						<Route path="*" component={NotFound} />
					</Switch>
				</Router>
			}
		</div>
	)
}

export default App
